@@ -83,6 +83,19 @@ class RobotKeywordsIndexerListener:
             pass
 
 
+class StatusEventListener:
+    ROBOT_LISTENER_API_VERSION = 2
+
+    def __init__(self, callback):
+        self.callback = callback
+
+    def start_test(self, name, attributes):
+        self.callback({"test": name})
+
+    def start_keyword(self, name, attributes):
+        self.callback({"keyword": name})
+
+
 class ReturnValueListener:
     ROBOT_LISTENER_API_VERSION = 2
 
@@ -90,11 +103,6 @@ class ReturnValueListener:
         self.return_value = None
 
     def end_keyword(self, name, attributes):
-        if "capture" in name.lower() and "screenshot" in name.lower():
-            # Intentional hack to not include screenshot keywords, because we
-            # can assume their screenshots be embedded into log file and
-            # displayed from that.
-            return
         frame = inspect.currentframe()
         while frame is not None:
             if "return_value" in frame.f_locals:
